class TextColor:
    ENDC = '\033[0m'  # default format

    CYAN = '\033[0;36m'  # debug
    OKBLUE = '\033[94m'  # info
    OKGREEN = '\033[92m'  # success
    YELLOW = '\033[93m'  # warning
    RED = '\033[91m'  # error/fail

    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

    MAGENTA = '\033[0;35m'
